# pylightdmx
A python module for basic lighting control with an Enttec DMX USB Pro Mk2.

### Installation
Use pip3 to install pylightdmx:
```
$ pip3 install pylighdmx
```

### License
GPLV3 © [ayork02](https://github.com/ayork02)

